@@ -31,10 +31,11 @@ class GraphicalTM : public TM
 {
   private:
   public:
-    GraphicalTM(string tm_file);
+    GraphicalTM(string tm_file, int tape_count);
     ~GraphicalTM();
     void loadTM(string filename);
     void loadInput(string filename);
+    void loadInput(vector<string> filenames);
     void print();
     bool cycle();
     GraphicalState* getStateAtPos(int x, int y);
