@@ -19,6 +19,7 @@
 
 #include "transition.h"
 
+/*
 Transition::Transition(State* begin_state, string input_symbol, 
                        string output_symbol, int movement, State* end_state)
 {
@@ -28,7 +29,18 @@ Transition::Transition(State* begin_state, string input_symbol,
   m_movement = movement;
   m_end_state = end_state;
 }
+*/
 
+Transition::Transition(State* begin_state, vector<string> input_symbols, 
+           vector<string> output_symbols, vector<int> movement, 
+           State* end_state)
+{
+  m_begin_state = begin_state;
+  m_input_symbols = input_symbols;
+  m_output_symbols = output_symbols;
+  m_movement = movement;
+  m_end_state = end_state;
+}
 Transition::~Transition()
 {
 }
