@@ -21,6 +21,7 @@
 #define __TRANSITION_H__
 
 #include <string>
+#include <vector>
 using namespace std;
 
 #include "state.h"
@@ -29,18 +30,23 @@ class Transition
 {
   private:
     State* m_begin_state;
-    string m_input_symbol;
-    string m_output_symbol;
-    int m_movement;
+    vector<string> m_input_symbols;
+    vector<string> m_output_symbols;
+    vector<int> m_movement;
     State* m_end_state;
   public:
+    /*
     Transition(State* begin_state, string input_symbol, string output_symbol, 
                int movement, State* end_state);
+	       */
+    Transition(State* begin_state, vector<string> input_symbols, 
+               vector<string> output_symbols, vector<int> movement, 
+               State* end_state);
     ~Transition();
-    string getInputSymbol() { return m_input_symbol; }
-    string getOutputSymbol() { return m_output_symbol; }
+    vector<string> getInputSymbols() { return m_input_symbols; }
+    vector<string> getOutputSymbols() { return m_output_symbols; }
     State* getBeginState() { return m_begin_state; }
-    int getMovement() { return m_movement; }
+    vector<int> getMovement() { return m_movement; }
     State* getEndState() { return m_end_state; }
 };
 
